@@ -1,12 +1,11 @@
-# $Id: PropertyList.pm,v 1.15 2004/02/03 21:30:35 comdog Exp $
+# $Id: PropertyList.pm,v 1.17 2004/09/03 01:12:49 comdog Exp $
 package Mac::PropertyList;
 use strict;
 
 use vars qw($ERROR $XML_head $XML_foot $VERSION);
-
 use Carp qw(croak);
 
-$VERSION = 0.51;
+$VERSION = 0.90;
 
 =head1 NAME
 
@@ -562,7 +561,7 @@ use base qw(Mac::PropertyList::Boolean);
 This source is part of a SourceForge project which always has the
 latest sources in CVS, as well as all of the previous releases.
 
-	https://sourceforge.net/projects/brian-d-foy/
+	http://sourceforge.net/projects/brian-d-foy/
 
 If, for some reason, I disappear from the world, one of the other
 members of the project can shepherd this module appropriately.
@@ -585,7 +584,7 @@ for help figuring out the recursion for nested structures.
 
 =head1 AUTHOR
 
-brian d foy, E<lt>bdfoy@cpan.orgE<gt>
+brian d foy, C<< <bdfoy@cpan.org> >>
 
 =head1 SEE ALSO
 
